<div style="margin-block: 1.2rem;">
    <ul class="step">
        {% for page in pages %}
            <li class="step-item {%- if page.id == page_id %} active {%- elif page.id < page_id and not page.eval_when %} skipped {%- endif %}">
                <a href="/page/{{ page.id }}" class="tooltip" data-tooltip="{{ page.title }}">Page {{ page.id + 1 }}</a>
            </li>
        {% endfor %}
    </ul>
</div>
